@@ -7,10 +7,10 @@ class Peeker(object):
     def __init__(self, api):
         self._api = api
 
-    def peek(self, topology, stream, count):
+    def peek(self, topology, stream, count, expressions='*'):
         limit = ''
         if count != 0:
             limit = '[LIMIT {0}]'.format(count)
-        query = 'SELECT RSTREAM {0} * FROM {1} [RANGE 1 TUPLES];'.format(limit, stream)
+        query = 'SELECT RSTREAM {0} {1} FROM {2} [RANGE 1 TUPLES];'.format(limit, expressions, stream)
         for data in self._api.query(topology, query):
             yield data
